summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/associationwidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:51:49 +0000
commit4ae0c208b66e0f7954e194384464fe2d0a2c56dd (patch)
treeb0a7cd1c184f0003c0292eb416ed27f674f9cc43 /umbrello/umbrello/associationwidget.h
parent1964ea0fb4ab57493ca2ebb709c8d3b5395fd653 (diff)
downloadtdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.tar.gz
tdesdk-4ae0c208b66e0f7954e194384464fe2d0a2c56dd.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1157652 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/associationwidget.h')
-rw-r--r--umbrello/umbrello/associationwidget.h108
1 files changed, 54 insertions, 54 deletions
diff --git a/umbrello/umbrello/associationwidget.h b/umbrello/umbrello/associationwidget.h
index 67739450..5034f016 100644
--- a/umbrello/umbrello/associationwidget.h
+++ b/umbrello/umbrello/associationwidget.h
@@ -132,7 +132,7 @@ public:
*
* @return Text of the given role's multiplicity widget.
*/
- QString getMulti(Uml::Role_Type role) const;
+ TQString getMulti(Uml::Role_Type role) const;
/**
* Read property of FloatingTextWidget* m_pName.
@@ -146,7 +146,7 @@ public:
*
* @return Text of the FloatingTextWidget name widget.
*/
- QString getName() const;
+ TQString getName() const;
/**
* Return the given role's FloatingTextWidget object.
@@ -167,24 +167,24 @@ public:
*
* @return The name set at the FloatingTextWidget.
*/
- QString getRoleName(Uml::Role_Type role) const;
+ TQString getRoleName(Uml::Role_Type role) const;
/**
* Returns the given role's documentation.
*/
- QString getRoleDoc(Uml::Role_Type role) const;
+ TQString getRoleDoc(Uml::Role_Type role) const;
/**
* Sets the text in the FloatingTextWidget widget representing the Name
* of this association.
*/
- void setName (const QString &strRole);
+ void setName (const TQString &strRole);
/**
* Sets the text in the FloatingTextWidget representing the multiplicity
* at the given side of the association.
*/
- void setMulti(const QString &strMulti, Uml::Role_Type role);
+ void setMulti(const TQString &strMulti, Uml::Role_Type role);
/**
* Gets the visibility on the given role of the association.
@@ -265,11 +265,11 @@ public:
void setAssocType(Uml::Association_Type type);
/**
* Returns a QString object representing this AssociationWidget.
*
* @return Textual representation of the AssociationWidget.
*/
- QString toString();
+ TQString toString();
/**
* Read property of bool m_bActivated.
@@ -347,27 +347,27 @@ public:
/**
* Adds a break point (if left mouse button).
*/
- void mouseDoubleClickEvent(QMouseEvent * me);
+ void mouseDoubleClickEvent(TQMouseEvent * me);
/**
* Sets the association to be selected.
*/
- void mousePressEvent(QMouseEvent * me);
+ void mousePressEvent(TQMouseEvent * me);
/**
* Displays the right mouse buttom menu if right button is pressed.
*/
- void mouseReleaseEvent(QMouseEvent * me);
+ void mouseReleaseEvent(TQMouseEvent * me);
/**
* Moves the break point being dragged.
*/
- void mouseMoveEvent(QMouseEvent * me);
+ void mouseMoveEvent(TQMouseEvent * me);
/**
* Returns true if the given point is on the Association.
*/
- bool onAssociation(const QPoint & point);
+ bool onAssociation(const TQPoint & point);
/**
* Returns true if the given point is on the connecting line to
@@ -375,7 +375,7 @@ public:
* class attached, or if the given point is not on the connecting
* line.
*/
- bool onAssocClassLine(const QPoint & point);
+ bool onAssocClassLine(const TQPoint & point);
/**
* Creates the association class connecting line.
@@ -411,18 +411,18 @@ public:
/**
* Returns the bounding rectangle of all segments of the association.
*/
- QRect getAssocLineRectangle();
+ TQRect getAssocLineRectangle();
/**
* Return the first font found being used by any child widget. (They
* could be different fonts, so this is a slightly misleading method.)
*/
- QFont getFont () const;
+ TQFont getFont () const;
/**
* Overrides the method from WidgetBase.
*/
- void setLineColor(const QColor &colour);
+ void setLineColor(const TQColor &colour);
/**
* Overrides the method from WidgetBase.
@@ -432,7 +432,7 @@ public:
/**
* Set all 'owned' child widgets to this font.
*/
- void lwSetFont (QFont font);
+ void lwSetFont (TQFont font);
/**
* Return the given role's changeability FloatingTextWidget widget.
@@ -445,12 +445,12 @@ public:
* For this function to work properly, the associated widget
* should already be set.
*/
- void setRoleName(const QString &strRole, Uml::Role_Type role);
+ void setRoleName(const TQString &strRole, Uml::Role_Type role);
/**
* Set the documentation on the given role.
*/
- void setRoleDoc(const QString &doc, Uml::Role_Type role);
+ void setRoleDoc(const TQString &doc, Uml::Role_Type role);
/**
* Overrides operation from LinkWidget.
@@ -475,13 +475,13 @@ public:
* Overrides operation from LinkWidget.
* Required by FloatingTextWidget.
*/
- QString getCustomOpText();
+ TQString getCustomOpText();
/**
* Overrides operation from LinkWidget.
* Required by FloatingTextWidget.
*/
- void setCustomOpText(const QString &opText);
+ void setCustomOpText(const TQString &opText);
/**
* Overrides operation from LinkWidget.
@@ -512,7 +512,7 @@ public:
* Overrides operation from LinkWidget.
* Required by FloatingTextWidget.
*/
- void setText(FloatingTextWidget *ft, const QString &text);
+ void setText(FloatingTextWidget *ft, const TQString &text);
/**
* Calls @ref setTextPosition() on all the labels.
@@ -572,7 +572,7 @@ public:
* @param seqNum The new sequence number string to set.
* @param op The new operation string to set.
*/
- void setSeqNumAndOp(const QString &seqNum, const QString &op);
+ void setSeqNumAndOp(const TQString &seqNum, const TQString &op);
/**
* Overrides operation from LinkWidget.
@@ -581,7 +581,7 @@ public:
* @param seqNum Return this AssociationWidget's sequence number string.
* @param op Return this AssociationWidget's operation string.
*/
- UMLClassifier * getSeqNumAndOp(QString& seqNum, QString& op);
+ UMLClassifier * getSeqNumAndOp(TQString& seqNum, TQString& op);
/**
* Calculates and sets the first and last point in the association's
@@ -613,12 +613,12 @@ public:
/**
* Saves this widget to the "assocwidget" XMI element.
*/
- void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+ void saveToXMI( TQDomDocument & qDoc, TQDomElement & qElement );
/**
* Loads this widget from the "assocwidget" XMI element.
*/
- bool loadFromXMI( QDomElement & qElement );
+ bool loadFromXMI( TQDomElement & qElement );
/**
* Same as above, but uses the supplied widgetList for resolving
@@ -626,7 +626,7 @@ public:
* the UMLView for these widgets.)
* Required for clipboard operations.
*/
- bool loadFromXMI( QDomElement & qElement, const UMLWidgetList& widgets,
+ bool loadFromXMI( TQDomElement & qElement, const UMLWidgetList& widgets,
const MessageWidgetList* pMessages = NULL);
/**
@@ -678,7 +678,7 @@ private:
* 8 = On diagonal 1 between Region4 and 1
* 9 = On diagonal 1 and On diagonal 2 (the center)
*/
- static Region findPointRegion(const QRect& Rect, int PosX, int PosY);
+ static Region findPointRegion(const TQRect& Rect, int PosX, int PosY);
/**
* Given a rectangle and a point, findInterceptOnEdge computes the
@@ -691,14 +691,14 @@ private:
* constant.)
* @todo This is buggy. Try replacing by findIntercept()
*/
- static int findInterceptOnEdge(const QRect &rect, Region region, const QPoint &point);
+ static int findInterceptOnEdge(const TQRect &rect, Region region, const TQPoint &point);
- static QPoint findIntercept(const QRect &rect, const QPoint &point);
+ static TQPoint findIntercept(const TQRect &rect, const TQPoint &point);
/**
* Overrides moveEvent.
*/
- void moveEvent(QMoveEvent *me);
+ void moveEvent(TQMoveEvent *me);
/**
* This function calculates which role should be set for the m_pName
@@ -710,13 +710,13 @@ private:
* Returns true if point (PosX, PosY) is close enough to any of the
* association's segments.
*/
- bool isPointInsideBoundaries(int PosX, int PosY, QPoint & SPoint,
+ bool isPointInsideBoundaries(int PosX, int PosY, TQPoint & SPoint,
uint & StartSegmentIndex, uint & EndSegmentIndex);
/**
* Returns a point with interchanged X and Y coordinates.
*/
- static QPoint swapXY(const QPoint &p);
+ static TQPoint swapXY(const TQPoint &p);
/**
* Returns the total length of the association's LinePath:
@@ -731,7 +731,7 @@ private:
* to Distance and if PX is not a point of the segment P1P2 then the
* function returns (-1,-1).
*/
- static QPoint calculatePointAtDistance(const QPoint &P1, const QPoint &P2, float Distance);
+ static TQPoint calculatePointAtDistance(const TQPoint &P1, const TQPoint &P2, float Distance);
/**
* Calculates which point of a perpendicular line to segment P1P2 that
@@ -739,7 +739,7 @@ private:
* Let's say such point is PX, the distance from P2 to PX must be equal
* to Distance.
*/
- static QPoint calculatePointAtDistanceOnPerpendicular(const QPoint &P1, const QPoint &P2, float Distance);
+ static TQPoint calculatePointAtDistanceOnPerpendicular(const TQPoint &P1, const TQPoint &P2, float Distance);
/**
* Calculates the intersection between line P1P2 and a perpendicular
@@ -748,19 +748,19 @@ private:
* P3. If this value is negative an error ocurred.
* This method is not currently used.
*/
- static float perpendicularProjection(const QPoint& P1, const QPoint& P2, const QPoint& P3, QPoint& ResultingPoint);
+ static float perpendicularProjection(const TQPoint& P1, const TQPoint& P2, const TQPoint& P3, TQPoint& ResultingPoint);
/**
* Return the mid point between p0 and p1
*/
- static QPoint midPoint(const QPoint& p0, const QPoint& p1);
+ static TQPoint midPoint(const TQPoint& p0, const TQPoint& p1);
/**
* Calculates the position of the text widget depending on the role
* that widget is playing.
* Returns the point at which to put the widget.
*/
- QPoint calculateTextPosition(Uml::Text_Role role);
+ TQPoint calculateTextPosition(Uml::Text_Role role);
/**
* Puts the text widget with the given role at the given position.
@@ -774,7 +774,7 @@ private:
* Moves the text widget with the given role by the difference between
* the two points.
*/
- void setTextPositionRelatively(Uml::Text_Role role, const QPoint &oldPosition);
+ void setTextPositionRelatively(Uml::Text_Role role, const TQPoint &oldPosition);
/**
* Returns the Region the widget to line intersection is for the given
@@ -829,7 +829,7 @@ private:
/**
* This role's old top left corner before moving.
*/
- QPoint m_OldCorner;
+ TQPoint m_OldCorner;
/**
* The region of this role's widget.
@@ -849,7 +849,7 @@ private:
// The following items are only used if m_pObject is not set.
Uml::Visibility m_Visibility;
Uml::Changeability_Type m_Changeability;
- QString m_RoleDoc;
+ TQString m_RoleDoc;
} m_role[2];
@@ -866,7 +866,7 @@ private:
* @param ft Reference to the pointer to FloatingTextWidget to change or create.
* On creation/deletion, the pointer value will be changed.
*/
- void setFloatingText(Uml::Text_Role tr, const QString &text, FloatingTextWidget* &ft);
+ void setFloatingText(Uml::Text_Role tr, const TQString &text, FloatingTextWidget* &ft);
/**
* Called to tell the association that another association has added
@@ -905,7 +905,7 @@ private:
* For internal purposes only.
* Other classes/users should use setChangeability() instead.
*/
- void setChangeWidget(const QString &strChangeWidget, Uml::Role_Type role);
+ void setChangeWidget(const TQString &strChangeWidget, Uml::Role_Type role);
/**
* Checks to see if the given point is one of the points of the line.
@@ -913,7 +913,7 @@ private:
* This is only valid if no other point id being moved and only
* while the left mouse button is down.
*/
- void checkPoints(const QPoint &p);
+ void checkPoints(const TQPoint &p);
/**
* Returns true if the line path starts at the given widget.
@@ -955,42 +955,42 @@ private:
/**
* Position of Name floatingtext saved by saveIdealTextPositions()
*/
- QPoint m_oldNamePoint;
+ TQPoint m_oldNamePoint;
/**
* Position of role A multiplicity floatingtext saved by
* saveIdealTextPositions()
*/
- QPoint m_oldMultiAPoint;
+ TQPoint m_oldMultiAPoint;
/**
* Position of role B multiplicity floatingtext saved by
* saveIdealTextPositions()
*/
- QPoint m_oldMultiBPoint;
+ TQPoint m_oldMultiBPoint;
/**
* Position of role A changeability floatingtext saved by
* saveIdealTextPositions()
*/
- QPoint m_oldChangeAPoint;
+ TQPoint m_oldChangeAPoint;
/**
* Position of role B changeability floatingtext saved by
* saveIdealTextPositions()
*/
- QPoint m_oldChangeBPoint;
+ TQPoint m_oldChangeBPoint;
/**
* Position of role A name floatingtext saved by
* saveIdealTextPositions()
*/
- QPoint m_oldRoleAPoint;
+ TQPoint m_oldRoleAPoint;
/**
* Position of role B name floatingtext saved by
* saveIdealTextPositions()
*/
- QPoint m_oldRoleBPoint;
+ TQPoint m_oldRoleBPoint;
int m_nLinePathSegmentIndex; ///< anchor for m_pAssocClassLine
- QCanvasLine *m_pAssocClassLine; ///< used for connecting assoc. class
+ TQCanvasLine *m_pAssocClassLine; ///< used for connecting assoc. class
/// selection adornment for the endpoints of the assoc. class connecting line
- QCanvasRectangle *m_pAssocClassLineSel0, *m_pAssocClassLineSel1;
+ TQCanvasRectangle *m_pAssocClassLineSel0, *m_pAssocClassLineSel1;
ClassifierWidget *m_pAssocClassWidget; ///< used if we have an assoc. class
@@ -265,11 +265,11 @@ public:
void setAssocType(Uml::Association_Type type);
/**
- * Returns a QString object representing this AssociationWidget.
+ * Returns a TQString object representing this AssociationWidget.
*
* @return Textual representation of the AssociationWidget.